@@ -2,15 +2,15 @@ use std::{cell::Cell, cell::RefCell, ptr::copy_nonoverlapping, rc::Rc, time};
 
 use crate::framed::Timer;
 use crate::http::{Request, Response};
-use crate::rt::time::{sleep, sleep_until, Instant, Sleep};
 use crate::service::boxed::BoxService;
+use crate::time::{sleep, Millis, Seconds, Sleep};
 use crate::util::BytesMut;
 
 #[derive(Debug, PartialEq, Clone, Copy)]
 /// Server keep-alive setting
 pub enum KeepAlive {
     /// Keep alive in seconds
-    Timeout(usize),
+    Timeout(Seconds),
     /// Relay on OS to shutdown tcp connection
     Os,
     /// Disabled
@@ -19,14 +19,14 @@ pub enum KeepAlive {
 
 impl From<usize> for KeepAlive {
     fn from(keepalive: usize) -> Self {
-        KeepAlive::Timeout(keepalive)
+        KeepAlive::Timeout(Seconds(keepalive as u16))
     }
 }
 
 impl From<Option<usize>> for KeepAlive {
     fn from(keepalive: Option<usize>) -> Self {
         if let Some(keepalive) = keepalive {
-            KeepAlive::Timeout(keepalive)
+            KeepAlive::Timeout(Seconds(keepalive as u16))
         } else {
             KeepAlive::Disabled
         }
@@ -37,12 +37,12 @@ impl From<Option<usize>> for KeepAlive {
 pub struct ServiceConfig(pub(super) Rc<Inner>);
 
 pub(super) struct Inner {
-    pub(super) keep_alive: u64,
-    pub(super) client_timeout: u64,
-    pub(super) client_disconnect: u64,
+    pub(super) keep_alive: Millis,
+    pub(super) client_timeout: Millis,
+    pub(super) client_disconnect: Seconds,
     pub(super) ka_enabled: bool,
     pub(super) timer: DateService,
-    pub(super) ssl_handshake_timeout: u64,
+    pub(super) ssl_handshake_timeout: Millis,
     pub(super) timer_h1: Timer,
     pub(super) lw: u16,
     pub(super) read_hw: u16,
@@ -57,7 +57,15 @@ impl Clone for ServiceConfig {
 
 impl Default for ServiceConfig {
     fn default() -> Self {
-        Self::new(KeepAlive::Timeout(5), 0, 0, 5000, 1024, 8 * 1024, 8 * 1024)
+        Self::new(
+            KeepAlive::Timeout(Seconds(5)),
+            Millis::ZERO,
+            Seconds::ZERO,
+            Millis(5_000),
+            1024,
+            8 * 1024,
+            8 * 1024,
+        )
     }
 }
 
@@ -65,23 +73,19 @@ impl ServiceConfig {
     /// Create instance of `ServiceConfig`
     pub fn new(
         keep_alive: KeepAlive,
-        client_timeout: u64,
-        client_disconnect: u64,
-        ssl_handshake_timeout: u64,
+        client_timeout: Millis,
+        client_disconnect: Seconds,
+        ssl_handshake_timeout: Millis,
         lw: u16,
         read_hw: u16,
         write_hw: u16,
     ) -> ServiceConfig {
         let (keep_alive, ka_enabled) = match keep_alive {
-            KeepAlive::Timeout(val) => (val as u64, true),
-            KeepAlive::Os => (0, true),
-            KeepAlive::Disabled => (0, false),
-        };
-        let keep_alive = if ka_enabled && keep_alive > 0 {
-            keep_alive
-        } else {
-            0
+            KeepAlive::Timeout(val) => (Millis::from(val), true),
+            KeepAlive::Os => (Millis::ZERO, true),
+            KeepAlive::Disabled => (Millis::ZERO, false),
         };
+        let keep_alive = if ka_enabled { keep_alive } else { Millis::ZERO };
 
         ServiceConfig(Rc::new(Inner {
             keep_alive,
@@ -104,9 +108,9 @@ pub(super) struct DispatcherConfig<T, S, X, U> {
     pub(super) service: S,
     pub(super) expect: X,
     pub(super) upgrade: Option<U>,
-    pub(super) keep_alive: time::Duration,
-    pub(super) client_timeout: u64,
-    pub(super) client_disconnect: u64,
+    pub(super) keep_alive: Millis,
+    pub(super) client_timeout: Millis,
+    pub(super) client_disconnect: Seconds,
     pub(super) ka_enabled: bool,
     pub(super) timer: DateService,
     pub(super) timer_h1: Timer,
@@ -129,7 +133,7 @@ impl<T, S, X, U> DispatcherConfig<T, S, X, U> {
             expect,
             upgrade,
             on_request,
-            keep_alive: time::Duration::from_secs(cfg.0.keep_alive),
+            keep_alive: cfg.0.keep_alive,
             client_timeout: cfg.0.client_timeout,
             client_disconnect: cfg.0.client_disconnect,
             ka_enabled: cfg.0.ka_enabled,
@@ -148,23 +152,16 @@ impl<T, S, X, U> DispatcherConfig<T, S, X, U> {
 
     /// Return keep-alive timer Sleep is configured.
     pub(super) fn keep_alive_timer(&self) -> Option<Sleep> {
-        if self.keep_alive.as_secs() != 0 {
-            Some(sleep_until(self.timer.now() + self.keep_alive))
-        } else {
-            None
-        }
+        self.keep_alive.map(sleep)
     }
 
     /// Keep-alive expire time
-    pub(super) fn keep_alive_expire(&self) -> Option<Instant> {
-        if self.keep_alive.as_secs() != 0 {
-            Some(self.timer.now() + self.keep_alive)
-        } else {
-            None
-        }
+    pub(super) fn keep_alive_expire(&self) -> Option<time::Instant> {
+        self.keep_alive
+            .map(|t| self.timer.now() + time::Duration::from(t))
     }
 
-    pub(super) fn now(&self) -> Instant {
+    pub(super) fn now(&self) -> time::Instant {
         self.timer.now()
     }
 }
@@ -187,7 +184,7 @@ impl Default for DateService {
 
 struct DateServiceInner {
     current: Cell<bool>,
-    current_time: Cell<Instant>,
+    current_time: Cell<time::Instant>,
     current_date: Cell<[u8; DATE_VALUE_LENGTH_HDR]>,
 }
 
@@ -195,14 +192,14 @@ impl DateServiceInner {
     fn new() -> Self {
         DateServiceInner {
             current: Cell::new(false),
-            current_time: Cell::new(Instant::now()),
+            current_time: Cell::new(time::Instant::now()),
             current_date: Cell::new(DATE_VALUE_DEFAULT),
         }
     }
 
     fn update(&self) {
         self.current.set(true);
-        self.current_time.set(Instant::now());
+        self.current_time.set(time::Instant::now());
 
         let mut bytes = DATE_VALUE_DEFAULT;
         let dt = httpdate::HttpDate::from(time::SystemTime::now()).to_string();
@@ -223,13 +220,13 @@ impl DateService {
             // periodic date update
             let s = self.clone();
             crate::rt::spawn(async move {
-                sleep(time::Duration::from_millis(500)).await;
+                sleep(Millis(500)).await;
                 s.0.current.set(false);
             });
         }
     }
 
-    fn now(&self) -> Instant {
+    pub(super) fn now(&self) -> time::Instant {
         self.check_date();
         self.0.current_time.get()
     }
@@ -275,6 +272,9 @@ mod tests {
     #[test]
     fn keep_alive() {
         assert_eq!(KeepAlive::Disabled, Option::<usize>::None.into());
-        assert_eq!(KeepAlive::Timeout(10), Option::<usize>::Some(10).into());
+        assert_eq!(
+            KeepAlive::Timeout(Seconds(10)),
+            Option::<usize>::Some(10).into()
+        );
     }
 }
