@@ -40,12 +40,17 @@ pub mod framed;
 pub mod http;
 pub mod server;
 pub mod testing;
+pub mod time;
 pub mod util;
 #[cfg(feature = "http-framework")]
 pub mod web;
 pub mod ws;
 
-pub use self::service::*;
+pub use self::service::{
+    apply_fn, boxed, fn_factory, fn_factory_with_config, fn_service, into_service,
+    pipeline, pipeline_factory, IntoService, IntoServiceFactory, Service,
+    ServiceFactory, Transform,
+};
 
 pub use futures_core::stream::Stream;
 pub use futures_sink::Sink;
